==> ckeditor_4.16.0+dfsg.orig.tar.xz: ckeditor4-4.16.0/plugins/link/lang/lv.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'lv', {
	acccessKey: 'Pieejas taustiņš',
	advanced: 'Izvērstais',
	advisoryContentType: 'Konsultatīvs satura tips',
	advisoryTitle: 'Konsultatīvs virsraksts',
	anchor: {
		toolbar: 'Ievietot/Labot iezīmi',
		menu: 'Labot iezīmi',
		title: 'Iezīmes uzstādījumi',
		name: 'Iezīmes nosaukums',
		errorName: 'Lūdzu norādiet iezīmes nosaukumu',
		remove: 'Noņemt iezīmi'
	},
	anchorId: 'Pēc elementa ID',
	anchorName: 'Pēc iezīmes nosaukuma',
	charset: 'Pievienotā resursa kodējums',
	cssClasses: 'Stilu saraksta klases',
	download: 'Piespiedu ielāde',
	displayText: 'Attēlot tekstu',
	emailAddress: 'E-pasta adrese',
	emailBody: 'Ziņas saturs',
	emailSubject: 'Ziņas tēma',
	id: 'ID',
	info: 'Hipersaites informācija',
	langCode: 'Valodas kods',
	langDir: 'Valodas lasīšanas virziens',
	langDirLTR: 'No kreisās uz labo (LTR)',
	langDirRTL: 'No labās uz kreiso (RTL)',
	menu: 'Labot hipersaiti',
	name: 'Nosaukums',
	noAnchors: '(Šajā dokumentā nav iezīmju)',
	noEmail: 'Lūdzu norādi e-pasta adresi',
	noUrl: 'Lūdzu norādi hipersaiti',
	noTel: 'Please type the phone number', // MISSING
	other: '<cits>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Atkarīgs (Netscape)',
	popupFeatures: 'Uznirstošā loga nosaukums īpašības',
	popupFullScreen: 'Pilnā ekrānā (IE)',
	popupLeft: 'Kreisā koordināte',
	popupLocationBar: 'Atrašanās vietas josla',
	popupMenuBar: 'Izvēlnes josla',
	popupResizable: 'Mērogojams',
	popupScrollBars: 'Ritjoslas',
	popupStatusBar: 'Statusa josla',
	popupToolbar: 'Rīku josla',
	popupTop: 'Augšējā koordināte',
	rel: 'Relācija',
	selectAnchor: 'Izvēlēties iezīmi',
	styles: 'Stils',
	tabIndex: 'Ciļņu indekss',
	target: 'Mērķis',
	targetFrame: '<ietvars>',
	targetFrameName: 'Mērķa ietvara nosaukums',
	targetPopup: '<uznirstošā logā>',
	targetPopupName: 'Uznirstošā loga nosaukums',
	title: 'Hipersaite',
	toAnchor: 'Iezīme šajā lapā',
	toEmail: 'E-pasts',
	toUrl: 'Adrese',
	toPhone: 'Phone', // MISSING
	toolbar: 'Ievietot/Labot hipersaiti',
	type: 'Hipersaites tips',
	unlink: 'Noņemt hipersaiti',
	upload: 'Augšupielādēt'
} );

==> ckeditor_4.22.1+dfsg1.orig.tar.xz: ckeditor4-4.22.1/plugins/link/lang/lv.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'lv', {
	acccessKey: 'Pieejas taustiņš',
	advanced: 'Izvērstais',
	advisoryContentType: 'Konsultatīvs satura tips',
	advisoryTitle: 'Konsultatīvs virsraksts',
	anchor: {
		toolbar: 'Ievietot/Labot iezīmi',
		menu: 'Labot iezīmi',
		title: 'Iezīmes uzstādījumi',
		name: 'Iezīmes nosaukums',
		errorName: 'Lūdzu norādiet iezīmes nosaukumu',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Noņemt iezīmi'
	},
	anchorId: 'Pēc elementa ID',
	anchorName: 'Pēc iezīmes nosaukuma',
	charset: 'Pievienotā resursa kodējums',
	cssClasses: 'Stilu saraksta klases',
	download: 'Piespiedu ielāde',
	displayText: 'Attēlot tekstu',
	emailAddress: 'E-pasta adrese',
	emailBody: 'Ziņojuma pamatteksts',
	emailSubject: 'Ziņojuma tēma',
	id: 'ID',
	info: 'Saites informācija',
	langCode: 'Valodas kods',
	langDir: 'Valodas lasīšanas virziens',
	langDirLTR: 'No kreisās uz labo (LTR)',
	langDirRTL: 'No labās uz kreiso (RTL)',
	menu: 'Rediģēt saiti',
	name: 'Nosaukums',
	noAnchors: '(Šajā dokumentā nav iezīmju)',
	noEmail: 'Lūdzu, ievadiet e-pasta adresi',
	noUrl: 'Lūdzu, ievadiet saites URL',
	noTel: 'Lūdzu, ievadiet tālruņa numuru',
	other: '<cits>',
	phoneNumber: 'Tālruņa numurs',
	popupDependent: 'Atkarīgs (Netscape)',
	popupFeatures: 'Uznirstošā loga nosaukums īpašības',
	popupFullScreen: 'Pilnā ekrānā (IE)',
	popupLeft: 'Kreisā koordināte',
	popupLocationBar: 'Atrašanās vietas josla',
	popupMenuBar: 'Izvēlnes josla',
	popupResizable: 'Mērogojams',
	popupScrollBars: 'Ritjoslas',
	popupStatusBar: 'Statusa josla',
	popupToolbar: 'Rīku josla',
	popupTop: 'Augšējā koordināte',
	rel: 'Relācija',
	selectAnchor: 'Izvēlēties iezīmi',
	styles: 'Stils',
	tabIndex: 'Ciļņu indekss',
	target: 'Mērķis',
	targetFrame: '<ietvars>',
	targetFrameName: 'Mērķa ietvara nosaukums',
	targetPopup: '<uznirstošā logā>',
	targetPopupName: 'Uznirstošā loga nosaukums',
	title: 'Saite',
	toAnchor: 'Iezīme šajā lapā',
	toEmail: 'E-pasts',
	toUrl: 'Adrese',
	toPhone: 'Tālrunis',
	toolbar: 'Saite',
	type: 'Saites tips',
	unlink: 'Atsaistīt',
	upload: 'Augšupielādēt'
} );
